
#include <avr/io.h>
#include <wprogram.h>

#define DHT11_DDR  DDRC
#define DHT11_PORT PORTC
#define DHT11_INP PINC
#define DHT11_PIN 0


void DHT11_init()
{
	DHT11_DDR |= (1<<DHT11_PIN);
	DHT11_DDR |= (1<<DHT11_PIN);
	
}

byte read_dht11_dat()
{
	byte i = 0;
	byte result=0;
	for(i=0; i< 8; i++){
		
		
		while(!(DHT11_INP & (1<<DHT11_PIN)));  // wait for 50us
		delayMicroseconds(30);
		
		if( DHT11_INP & (1<<DHT11_PIN)) 
			result |=(1<<(7-i));
    while(DHT11_INP & (1<<DHT11_PIN));  // wait '1' finish
         
		
	}
	return result;
}


	
int DHT11_read(byte *hum_int, byte *hum_dec, byte *temp_int, byte *temp_dec)
{
	byte dht11_dat[5];
	byte dht11_in;
	byte i;
	// start condition
	// 1. pull-down i/o pin from 18ms
	 DHT11_PORT &= ~(1<<DHT11_PIN);
	delay(18);
	DHT11_PORT |= (1<<DHT11_PIN);
	delayMicroseconds(40);
	
	DHT11_DDR &= ~(1<<DHT11_PIN);
	delayMicroseconds(40);
	
	dht11_in = DHT11_INP & (1<<DHT11_PIN);
	
	if(dht11_in){
		//Serial.println("dht11 start condition 1 not met");
		return -1;
	}
	delayMicroseconds(80);
	
	dht11_in = DHT11_INP & (1<<DHT11_PIN);
	
	if(!dht11_in){
		//Serial.println("dht11 start condition 2 not met");
		return -2;
	}
	delayMicroseconds(80);
	// now ready for data reception
	for (i=0; i<5; i++)
		dht11_dat[i] = read_dht11_dat();
		
	DHT11_DDR |= (1<<DHT11_PIN);
	DHT11_PORT |= (1<<DHT11_PIN);
	
  byte dht11_check_sum = dht11_dat[0]+dht11_dat[1]+dht11_dat[2]+dht11_dat[3];
	// check check_sum
	if(dht11_dat[4]!= dht11_check_sum)
	{
		return -3;
	}
	
	*hum_int = dht11_dat[0];
	*hum_dec = dht11_dat[1];
	*temp_int = dht11_dat[2];
	*temp_dec = dht11_dat[3];
	
	return 0;
	
}
